<?php
/**
 * The main ONLINEmaps settings page.
 *
 * @package locrMAPS
 */

declare(strict_types=1);

namespace Locr\WordPress\Plugin\LocrMaps\Admin\SettingsPage\OnlineMaps;

use Locr\WordPress\Plugin\LocrMaps\Admin\OnlineMapsTable;
use Locr\WordPress\Plugin\LocrMaps\Admin\SettingsPage\OnlineMaps;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * This class is responsible for rendering the main online maps settings page.
 */
final class Main {
	/**
	 * This function renders the main online maps settings page.
	 */
	public static function render(): void {
		$admin_url = admin_url( 'admin.php' );
		$table     = new OnlineMapsTable();

		$query_args           = array(
			'page'     => OnlineMaps::SUB_PAGE_NAME,
			'action'   => 'create',
			'_wpnonce' => wp_create_nonce( Create::NONCE_ACTION ),
		);
		$create_onlinemap_url = add_query_arg( $query_args, $admin_url );

		print '<div class="wrap">' . PHP_EOL;
		print '			<h1>';
		print esc_html__( 'locrMAPS', 'locrmaps-textdomain' ) . ' &rsaquo; ' . esc_html__( 'ONLINEmaps', 'default' );
		print '&nbsp;<a href="' . esc_attr( $create_onlinemap_url ) . '" class="button button-secondary">' . esc_html__( 'Create', 'default' ) . '</a>';
		print '</h1>' . PHP_EOL;

		settings_errors();

		print '			<form id="' . esc_attr( OnlineMaps::SUB_PAGE_NAME . '-form' ) . '" method="post">' . PHP_EOL;
		$table->prepare_items();
		$table->display();
		print '			</form>' . PHP_EOL;
		print '		</div>' . PHP_EOL;
	}
}
