<?php
/**
 * This is the entrypoint for the locrMAPS WordPress plugin.
 *
 * @package locrMAPS
 */

declare(strict_types=1);

namespace Locr\WordPress\Plugin\LocrMaps\Filters;

use Locr\WordPress\Plugin\LocrMaps\DDD\Entities\Icon;
use Locr\WordPress\Plugin\LocrMaps\DDD\Repositories\Icons as IconsRepository;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * This class is responsible for the icons filters.
 */
final class Icons {
	/**
	 * This initializes the icons filters.
	 */
	public static function init(): void {
		add_filter( 'locrmaps_icon_data', array( self::class, 'icon_data' ) );
		add_filter( 'locrmaps_icon_names', array( self::class, 'icon_names' ) );
	}

	/**
	 * This function enqueues the styles for the leaflet.
	 *
	 * @return array<array<mixed>> The icon data.
	 */
	public static function icon_data(): array {
		$icons_repository = new IconsRepository();
		$icons            = $icons_repository->get_all_icons_as_associative();

		$result = array();
		foreach ( $icons as $name => $icon ) {
			if ( $icon instanceof Icon ) {
				$result[ $name ] = $icon->to_array();
			}
		}

		return $result;
	}

	/**
	 * This function enqueues the styles for the leaflet.
	 *
	 * @return array<string> The icon names.
	 */
	public static function icon_names(): array {
		$icons_repository = new IconsRepository();
		$icons            = $icons_repository->get_all_icons();

		$result = array();
		foreach ( $icons as $icon ) {
			if ( $icon instanceof Icon ) {
				$result[] = (string) $icon->name;
			}
		}
		asort( $result );

		return $result;
	}
}
