<?php
/**
 * This is the entrypoint for the locrMAPS WordPress plugin.
 *
 * @package locrMAPS
 */

declare(strict_types=1);

namespace Locr\WordPress\Plugin\LocrMaps\Filters;

use Locr\WordPress\Plugin\LocrMaps\DDD\Repositories\Styles as StylesRepository;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * This class is responsible for the styles filters.
 */
final class Styles {
	/**
	 * This initializes the styles filters.
	 */
	public static function init(): void {
		add_filter( 'locrmaps_style_names', array( self::class, 'style_names' ) );
	}

	/**
	 * This function enqueues the styles for the leaflet.
	 *
	 * @return array<string> The style names.
	 */
	public static function style_names(): array {
		$styles_repository = new StylesRepository();
		$styles            = $styles_repository->get_all();

		$result = array();
		foreach ( $styles as $style ) {
			$result[] = $style;
		}
		asort( $result );

		return $result;
	}
}
